NAME
WWW::MenuGrinder::Plugin::ActivePath - WWW::MenuGrinder plugin that finds a path to the currently active page.
VERSION
version 0.01_01
DESCRIPTION
WWW::MenuGrinder::Plugin::ActivePath is a plugin for WWW::MenuGrinder. You should not use it directly, but include it in the plugins section of a WWW::MenuGrinder config.
When loaded, this plugin will visit each item of the menu, comparing any item with a location attribute to the current URL path. The item that best matches the current path will have its active key set to "yes", and each of its ancestors will have its active key set to "child".
Configuration
None.
Required Methods
In order to load this plugin your WWW::MenuGrinder subclass must implement the method path returning a path name for the current request.
Dependencies
WWW::MenuGrinder::Plugin::Visitor.
Other Considerations
It's advisable to load this plugin after any plugins that may remove items from the menu, to ensure that the chain of active items is unbroken.
AUTHOR
Andrew Rodland <andrew@hbslabs.com>
COPYRIGHT AND LICENSE
This software is copyright (c) 2009 by HBS Labs, LLC..
This is free software; you can redistribute it and/or modify it under the same terms as perl itself.